summaryrefslogtreecommitdiffstats
path: root/chrome/browser/cocoa/reload_button.h
diff options
context:
space:
mode:
authorBen Murdoch <benm@google.com>2010-11-18 18:32:45 +0000
committerBen Murdoch <benm@google.com>2010-11-18 18:38:07 +0000
commit513209b27ff55e2841eac0e4120199c23acce758 (patch)
treeaeba30bb08c5f47c57003544e378a377c297eee6 /chrome/browser/cocoa/reload_button.h
parent164f7496de0fbee436b385a79ead9e3cb81a50c1 (diff)
downloadexternal_chromium-513209b27ff55e2841eac0e4120199c23acce758.zip
external_chromium-513209b27ff55e2841eac0e4120199c23acce758.tar.gz
external_chromium-513209b27ff55e2841eac0e4120199c23acce758.tar.bz2
Merge Chromium at r65505: Initial merge by git.
Change-Id: I31d8f1d8cd33caaf7f47ffa7350aef42d5fbdb45
Diffstat (limited to 'chrome/browser/cocoa/reload_button.h')
-rw-r--r--chrome/browser/cocoa/reload_button.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/cocoa/reload_button.h b/chrome/browser/cocoa/reload_button.h
index 493da1c..edb6e9c 100644
--- a/chrome/browser/cocoa/reload_button.h
+++ b/chrome/browser/cocoa/reload_button.h
@@ -20,9 +20,8 @@
BOOL isMouseInside_;
scoped_nsobject<NSTrackingArea> trackingArea_;
- // Set when reload mode is requested, but not forced, and the mouse
- // is hovering.
- BOOL pendingReloadMode_;
+ // Timer used when setting reload mode while the mouse is hovered.
+ scoped_nsobject<NSTimer> pendingReloadTimer_;
}
// Returns YES if the mouse is currently inside the bounds.
@@ -32,13 +31,14 @@
// |isLoading|. If |force|, always sets the indicated mode. If
// |!force|, and the mouse is over the button, defer the transition
// from stop button to reload button until the mouse has left the
-// button. This prevents an inadvertent click _just_ as the state
-// changes.
+// button, or until |pendingReloadTimer_| fires. This prevents an
+// inadvertent click _just_ as the state changes.
- (void)setIsLoading:(BOOL)isLoading force:(BOOL)force;
@end
@interface ReloadButton (PrivateTestingMethods)
++ (void)setPendingReloadTimeout:(NSTimeInterval)seconds;
- (NSTrackingArea*)trackingArea;
@end